#' @name PaulinoTb9.15
#' @title Dependência de tóxicos em Alunos   
#' @description Inquérito feito com alunos do terceiro ciclo do ensino
#'     básico em escolas de Lisboa, sendo estes participantes de um
#'     programa de prevenção a toxicodependência. O inquérito foi
#'     realizado em duas etapas, a primeira em 1991, ano de início do
#'     programa, e a segunda em 1994.
#' @format Um \code{data.frame} com 48 observações e 5 variáveis, em que
#'
#' \describe{
#'
#' \item{\code{ano}}{Ano da realização do inquérito (1991, 1994).}
#'
#' \item{\code{sexo}}{Sexo do aluno (masculino, feminino).}
#'
#' \item{\code{agreg}}{Tipo de agregado doméstico (família nuclear, 
#'     monoparental ou reconstituída, alargada e família sem presença
#'     dos pais).}
#'
#' \item{\code{drogas}}{Consumo de drogas (não-cosumidor, consumidor
#'     apenas de drogas lícitas e consumidor de drogas ilícitas).}
#'
#' \item{\code{nalunos}}{Número de alunos.}
#'
#' }
#' @keywords contingência dados-categóricos
#' @source PAULINO; SINGER (2006), Tabela 9.15, pág. 286.
#' @examples
#'
#' data(PaulinoTb9.15)
#'
#' str(PaulinoTb9.15)
#'
#' xt <- xtabs(nalunos ~ ., data = PaulinoTb9.15)
#' ftable(xt)
#'
#' library(lattice)
#' library(latticeExtra)
#' 
#' useOuterStrips(
#'     barchart(nalunos ~ drogas | agreg + factor(ano), groups = sexo,
#'              horizontal = FALSE,
#'              data = PaulinoTb9.15,
#'              auto.key = list(space = "top", columns = 2,
#'                              cex.title = 1, rectangles = TRUE,
#'                              points = FALSE, title = "Sexo"),
#'              xlab = "Drogas",
#'              ylab = "Número de alunos")
#' )
#'
NULL