#' @name PaulinoTb9.24
#' @title Lesão Arterial em uma Artéria Coronariana
#' @description Estudo realizado em pacientes de uma clínica
#'     particular de cardiologia no período de 1989-1994.
#' @format Um \code{data.frame} com 16 observações e 5 variáveis, em que
#'
#' \describe{
#'
#' \item{\code{sexo}}{Sexo do paciente (feminino, masculino).}
#'
#' \item{\code{idade}}{Idade do paciente (< 55 ou > 54).}
#'
#' \item{\code{hipert}}{Hipertensão do paciente (sim ou não).}
#'
#' \item{\code{grau}}{Grau de lesão arterial obstrutiva expressiva em
#'     pelo menos uma artéria coronariana (< 50\% ou > 49\%)}
#'
#' \item{\code{freq}}{Frequências observadas dos 1448 pacientes
#'     cardíacos.}
#'
#' }
#' @keywords contingência dicotomicas
#' @source PAULINO; SINGER (2006), Tabela 9.24, pág. 316.
#' @examples
#'
#' data(PaulinoTb9.24)
#'
#' str(PaulinoTb9.24)
#'
#' xt <- xtabs(freq ~ ., data = PaulinoTb9.24)
#' ftable(xt)
#'
#' library(lattice)
#' library(latticeExtra)
#'
#' useOuterStrips(
#'     barchart(freq ~ hipert | idade + grau, groups = sexo,
#'              horizontal = FALSE, stack = TRUE,
#'              data = PaulinoTb9.24,
#'              auto.key = list(space = "top", columns = 2,
#'                              cex.title = 1, rectangles = TRUE,
#'                              points = FALSE, title = "Sexo"),
#'              xlab = "Hipertensão",
#'              ylab = "Frequência")
#' )
#'
NULL